From: Julian Phillips Date: Tue, 17 Apr 2007 20:17:14 GMT Subject: Re: [PATCH] refs.c: add a function to sort a ref list, rather then sorting on add Message-ID: In-Reply-To: On Tue, 17 Apr 2007, Linus Torvalds wrote: > > > On Tue, 17 Apr 2007, Julian Phillips wrote: >> >> Rather than sorting the refs list while building it, sort in one go >> after it is built using a merge sort. This has a large performance >> boost with large numbers of refs. >> >> Signed-off-by: Julian Phillips > > Acked-by: Linus Torvalds > > Looks fine. I think that even your new times are a bit high (over two > seconds?) but things are clearly better. Have you looked at what takes so > long now? It's the tag auto-following code, I'm calling read_ref to see if I already have that tag - and it appears that doing that a few thousand times takes a while. If I comment out that one line (so the code will _always_ think I have the tags - but I do have them, so ...) I get: real 0m0.472s user 0m0.277s sys 0m0.181s Looks like read_ref is the wrong thing to be using ... -- Julian --- "Life is like a buffet; it's not good but there's plenty of it."